@@ -1,5 +1,5 @@
-import PythonPals.Button
-import PythonPals.questions
+from PythonPals.Button import *
+from PythonPals.questions import *
 import pygame
 import pygame.gfxdraw
 import textwrap
